/* eslint-env node jest */
import { enableFetchMocks } from "jest-fetch-mock";
enableFetchMocks();
import {
  generateUserId,
  parseUri,
  ping,
} from "../src/background/utils/utils.js";

beforeEach(() => {
  fetch.resetMocks();
});

test("id generated", () => {
  expect(generateUserId().length).toBe(16);
});

test("parse url", () => {
  const url = parseUri("https://host:8080/path/to/target");
  expect(url.host).toBe("host:8080");
  expect(url.hostname).toBe("host");
  expect(url.port).toBe("8080");
});

test("ping", async () => {
  fetch.mockResponseOnce("Hello World!");
  const result = await ping({});

  expect(result.data).toEqual("Hello World!");
  expect(fetch.mock.calls.length).toEqual(1);
  expect(fetch.mock.calls[0][0]).toEqual("https://ping.ublock.org/api/stats");
  // should we verify method is POST, content type is application/json?
});
